@@ -1,5 +1,5 @@
 // Network encoding for lightning network peer protocol data types
-// Written in 2020 by
+// Written in 2020-2022 by
 //     Dr. Maxim Orlovsky <orlovsky@pandoracore.com>
 //
 // To the extent possible under law, the author(s) have dedicated all
@@ -84,6 +84,10 @@ impl Strategy for lnpbp::chain::AssetId {
     type Strategy = strategies::AsStrict;
 }
 
+impl Strategy for lnpbp::bech32::Blob {
+    type Strategy = strategies::AsWrapped;
+}
+
 impl LightningEncode for Script {
     #[inline]
     fn lightning_encode<E: Write>(&self, e: E) -> Result<usize, Error> {
